@@ -52,10 +52,24 @@
 /*
  * Define this if you do not want nmh to attach the local hostname
  * to local addresses.  You must also define DUMB.  You probably
- * dont' need this unless you are behind a firewall.
+ * don't need this unless you are behind a firewall.
  */
 /* #define REALLYDUMB  1 */
 
+/*
+ * Starting on January 1, 2000, some MUAs like ELM and Ultrix's DXmail started
+ * generated bad dates ("00" or "100" for the year).  If this #define is active,
+ * we use windowing to correct those dates to what we presume to be the intended
+ * values.  About the only time this could get us into trouble would be if a MUA
+ * was generating a year of "00" in 2001 or later, due to an unrelated bug.  In
+ * this case we would "correct" the year to 2000, which could result in
+ * inaccurate bug reports against the offending MUA.  A much more esoteric case
+ * in which you might not want to #define this would be if you were OCR'ing in
+ * old written correspondence and saving it in email format, and you had dates
+ * of 1899 or earlier.
+ */
+#define FIX_NON_Y2K_COMPLIANT_MUA_DATES 1
+
 /*
  * Directs inc/slocal to extract the envelope sender from "From "
  * line.  If inc/slocal is saving message to folder, then this
@@ -86,19 +100,19 @@
 #define BUILTIN_FTP 1
 
 /*
- * If you enable POP support, this is the the port name
- * that nmh will use.  Make sure this is defined in your
- * /etc/services file (or its NIS/NIS+ equivalent).  If you
- * are using KPOP, you will probably need to change this
- * to "kpop".
+ * If you enable POP support, this is the the port name that nmh will use.  Make
+ * sure this is defined in your /etc/services file (or its NIS/NIS+ equivalent).
+ * If you are using KPOP, you will need to change this to "kpop" unless you want
+ * to be able to use both POP3 _and_ Kerberized POP and plan to use inc and
+ * msgchk's -kpop switch every time in the latter case.
  */
 #define POPSERVICE "pop3"
 
 /*
  * Define the default creation modes for folders and messages.
  */
-#define DEFAULT_FOLDER_MODE "0700"
-#define DEFAULT_MESSAGE_MODE "0600"
+#define DEFAULT_FOLDER_MODE "700"
+#define DEFAULT_MESSAGE_MODE "600"
 
 /*
  * The prefix which is prepended to the name of messages when they
@@ -163,8 +177,8 @@
 /*
  * Define this to compile client-side support for pop into
  * inc and msgchk.  Do not change this value manually.  You
- * must run configure with the '--enable-nmh-pop' option
- * to correctly build the pop client support.
+ * must run configure with the '--enable-pop' option to
+ * correctly build the pop client support.
  */
 #undef POP
 
@@ -264,6 +278,11 @@
 /* Define if your system has db1/ndbm.h instead of ndbm.h (ppclinux) */
 #undef HAVE_DB1_NDBM_H
 
+/* Define to the header containing the declaration of initgroups() on your
+   system, if any.  AIX 4.[13], SunOS 4.1.3, and ULTRIX 4.2A have the function
+   in libc but don't have a declaration anywhere. */
+#undef INITGROUPS_HEADER
+
 /* Define if your system actually has a prototype for snprintf() in <stdio.h>
    (or a file it includes) rather than just having a "stealth" definition of it
    in libc.a the way AIX 4.1 does. */
