@@ -2,7 +2,7 @@
 /*
  * popsbr.h -- header for POP client subroutines
  *
- * $Id: popsbr.h,v 1.1.1.1 1999/04/30 18:08:34 doug Exp $
+ * $Id: popsbr.h,v 1.2 2000/02/04 01:32:12 danh Exp $
  */
 
 #if 0
@@ -22,7 +22,7 @@ int pop_set (int, int, int);
 int pop_exists (int (*)());
 #endif
 
-int pop_init (char *, char *, char *, int, int);
+int pop_init (char *, char *, char *, int, int, int);
 int pop_fd (char *, int, char *, int);
 int pop_stat (int *, int *);
 int pop_retr (int, int (*)());
