@@ -2,7 +2,7 @@
 /*
  * prototypes.h -- various prototypes
  *
- * $Id: prototypes.h,v 1.3 1999/09/12 13:50:11 doug Exp $
+ * $Id: prototypes.h,v 1.4 2000/01/25 06:18:54 danh Exp $
  */
 
 /*
@@ -129,11 +129,14 @@ int get_returnpath (char *, int, char *, int);
 /*
  * prototypes for compatibility functions in library
  */
-#ifndef HAVE_SNPRINTF
+#ifndef HAVE_SNPRINTF_PROTOTYPE
 int snprintf (char *, size_t, const char *, ...);
 int vsnprintf (char *, size_t, const char *, va_list);
 #endif
 
+int strcasecmp (const char *s1, const char *s2);
+int strncasecmp (const char *s1, const char *s2, size_t n);
+
 #ifndef HAVE_STRERROR
 char *strerror (int);
 #endif
