@@ -2,13 +2,19 @@
 /*
  * smtp.c -- nmh SMTP interface
  *
- * $Id$
+ * $Id: smtp.c,v 1.6 1999/09/26 17:45:56 ruud Exp $
  */
 
 #include <h/mh.h>
 #include "smtp.h"
 #include <zotnet/mts/mts.h>
 #include <signal.h>
+#include <h/signals.h>
+#ifdef MPOP
+#include <errno.h>
+#endif
+
+
 
 /*
  * This module implements an interface to SendMail very similar
@@ -71,10 +77,6 @@ static char *sm_moreply = "; ";
 
 struct smtp sm_reply;		/* global... */
 
-#ifdef MPOP
-extern int errno;
-#endif
-
 
 #define	MAXEHLO	20
 
@@ -102,9 +104,11 @@ static char *EHLOset (char *);
  */
 static char **smail_brkstring (char *, char *, char *);
 static int smail_brkany (char, char *);
-char **smail_copyip (char **, char **);
+char **smail_copyip (char **, char **, int);
 #endif
 
+/* from zotnet/mts/client.c */
+int client (char *, char *, char *, int, char *, int);
 
 int
 sm_init (char *client, char *server, int watch, int verbose,
@@ -126,11 +130,13 @@ sm_init (char *client, char *server, int watch, int verbose,
     if (sm_rfp != NULL && sm_wfp != NULL)
 	goto send_options;
 
-    if (client == NULL || *client == '\0')
-	if (clientname)
+    if (client == NULL || *client == '\0') {
+	if (clientname) {
 	    client = clientname;
-	else
+	} else {
 	    client = LocalName();	/* no clientname -> LocalName */
+	}
+    }
 
 #ifdef ZMAILER
     if (client == NULL || *client == '\0')
@@ -231,7 +237,7 @@ rclient (char *server, char *protocol, char *service)
     char *cp;
 #endif /* MPOP */
 
-    if ((sd = client (server, protocol, service, FALSE, response)) != NOTOK)
+    if ((sd = client (server, protocol, service, FALSE, response, sizeof(response))) != NOTOK)
 	return sd;
 
 #ifdef MPOP
@@ -239,7 +245,7 @@ rclient (char *server, char *protocol, char *service)
 	char **ap;
 	char *arguments[MAXARGS];
 
-	smail_copyip (smail_brkstring (cp = getcpy (servers), " ", "\n"), arguments);
+	smail_copyip (smail_brkstring (cp = getcpy (servers), " ", "\n"), arguments, MAXARGS);
 
 	for (ap = arguments; *ap; ap++)
 	    if (**ap == '/') {
@@ -247,13 +253,17 @@ rclient (char *server, char *protocol, char *service)
 
 		if ((dp = strrchr(*ap, '/')) && *++dp == NULL)
 		    *--dp = NULL;
-		sprintf (sm_tmpfil, "%s/smtpXXXXXX", *ap);
+		snprintf (sm_tmpfil, sizeof(sm_tmpfil), "%s/smtpXXXXXX", *ap);
+#ifdef HAVE_MKSTEMP
+		sd = mkstemp (sm_tmpfil);
+#else
 		mktemp (sm_tmpfil);
 
 		if ((sd = creat (sm_tmpfil, 0600)) != NOTOK) {
 		    sm_ispool = 1;
 		    break;
 		}
+#endif
 	    }
 
 	free (cp);
@@ -490,12 +500,17 @@ sm_bulk (char *file)
     gp = NULL;
     k = strlen (file) - sizeof(".bulk");
     if ((fp = fopen (file, "r")) == NULL) {
-	sprintf (bp = sm_reply.text, "unable to read %s: ", file);
-	bp += strlen (bp);
+	int len;
+
+	snprintf (sm_reply.text, sizeof(sm_reply.text),
+		"unable to read %s: ", file);
+	bp = sm_reply.text;
+	len = strlen (bp);
+	bp += len;
 	if ((s = strerror (errno)))
-	    strcpy (bp, s);
+	    strncpy (bp, s, sizeof(sm_reply.text) - len);
 	else
-	    sprintf (bp, "Error %d", errno);
+	    snprintf (bp, sizeof(sm_reply.text) - len, "Error %d", errno);
 	sm_reply.length = strlen (sm_reply.text);
 	sm_reply.code = NOTOK;
 	return RP_BHST;
@@ -508,7 +523,7 @@ sm_bulk (char *file)
     i = j = 0;
     while (fgets (buffer, sizeof(buffer), fp)) {
 	if (j++ == 0)
-	    strcpy (sender, buffer + sizeof("MAIL FROM:") - 1);
+	    strncpy (sender, buffer + sizeof("MAIL FROM:") - 1, sizeof(sender));
 	if (strcmp (buffer, "DATA\r\n") == 0) {
 	    i = 1;
 	    break;
@@ -519,11 +534,11 @@ sm_bulk (char *file)
 	    printf ("no DATA...\n");
 	    fflush (stdout);
 	}
-losing0: ;
-	sprintf (buffer, "%s.bad", file);
+losing0:
+	snprintf (buffer, sizeof(buffer), "%s.bad", file);
 	rename (file, buffer);
 	if (gp) {
-	    sprintf (buffer, "%*.*sA.bulk", k, k, file);
+	    snprintf (buffer, sizeof(buffer), "%*.*sA.bulk", k, k, file);
 	    unlink (buffer);
 	    fclose (gp);
 	}
@@ -549,7 +564,7 @@ losing1: ;
     for (dp = cp, i = 0; i++ < j; dp += strlen (dp))
 	if (fgets (dp, cc - (dp - cp), fp) == NULL) {
 	    sm_reply.length = strlen (strcpy (sm_reply.text, "premature eof"));
-losing2: ;
+losing2:
 	    free (cp);
 	    goto losing1;
 	}
@@ -557,13 +572,18 @@ losing2: ;
 
     for (dp = cp, i = cc - 1; i > 0; dp += cc, i -= cc)
 	if ((cc = write (fileno (sm_wfp), dp, i)) == NOTOK) {
-losing3: ;
-	    strcpy (bp = sm_reply.text, "error writing to server: ");
-	    bp += strlen (bp);
+	    int len;
+losing3:
+	    strcpy (sm_reply.text, "error writing to server: ",
+		sizeof(sm_reply.text));
+	    bp = sm_reply.text;
+	    len = strlen (bp);
+	    bp += len;
 	    if ((s = strerror (errno)))
-		strcpy (bp, s);
+		strncpy (bp, s, sizeof(sm_reply.text) - len);
 	    else
-		sprintf (bp, "unknown error %d", errno);
+		snprintf (bp, sizeof(sm_reply.text) - len,
+			"unknown error %d", errno);
 	    sm_reply.length = strlen (sm_reply.text);
 	    goto losing2;
 	}
@@ -622,12 +642,12 @@ losing3: ;
 	    case 2000 + 552: 
 	    case 2000 + 553: 
 		result = RP_USER;
-bad_addr: ;
+bad_addr:
 		if (k <= 0 || strcmp (sender, "<>\r\n") == 0)
 		    break;
 		if (gp == NULL) {
 		    int	    l;
-		    sprintf (buffer, "%*.*sA.bulk", k, k, file);
+		    snprintf (buffer, sizeof(buffer), "%*.*sA.bulk", k, k, file);
 		    if ((gp = fopen (buffer, "w+")) == NULL)
 			goto bad_data;
 		    fprintf (gp, "MAIL FROM:<>\r\nRCPT TO:%sDATA\r\n", sender);
@@ -649,7 +669,7 @@ bad_addr: ;
 
 	    case 3000 + 354: 
 #ifdef SENDMAILBUG
-ok_data: ;
+ok_data:
 #endif
 		result = RP_OK;
 		break;
@@ -660,11 +680,11 @@ ok_data: ;
 #endif
 	    case 3000 + 421:
 		result = RP_NO;
-bad_data: ;
+bad_data:
 		smtalk (SM_RSET, "RSET");
 		free (cp);
 		if (gp) {
-		    sprintf (buffer, "%*.*sA.bulk", k, k, file);
+		    snprintf (buffer, sizeof(buffer), "%*.*sA.bulk", k, k, file);
 		    unlink (buffer);
 		    fclose (gp);
 		}
@@ -701,19 +721,26 @@ bad_data: ;
 	    goto losing1;
 	}
     }
+
     fseek (fp, pos, SEEK_SET);
     for (;;) {
-	int	eof = 0;
+	int eof = 0;
 
 	for (dp = cp, i = cc; i > 0; dp += j, i -= j)
 	    if ((j = fread (cp, sizeof(*cp), i, fp)) == OK) {
 		if (ferror (fp)) {
-		    sprintf (bp = sm_reply.text, "error reading %s: ", file);
-		    bp += strlen (bp);
+		    int len;
+
+		    snprintf (sm_reply.text, sizeof(sm_reply.text),
+			"error reading %s: ", file);
+		    bp = sm_reply.text;
+		    len = strlen (bp);
+		    bp += len;
 		    if ((s = strerror (errno)))
-			strcpy (bp, s);
+			strncpy (bp, s, sizeof(sm_reply.text) - len);
 		    else
-			sprintf (bp, "unknown error %d", errno);
+			snprintf (bp, sizeof(sm_reply.text) - len,
+				"unknown error %d", errno);
 		    sm_reply.length = strlen (sm_reply.text);
 		    goto losing2;
 		}
@@ -740,7 +767,7 @@ bad_data: ;
 	case 250: 
 	case 251: 
 #ifdef SENDMAILBUG
-ok_dot: ;
+ok_dot:
 #endif
 	    result = RP_OK;
 	    unlink (file);
@@ -754,7 +781,7 @@ ok_dot: ;
 	default: 
 	    result = RP_NO;
 	    if (gp) {
-		sprintf (buffer, "%*.*sA.bulk", k, k, file);
+		snprintf (buffer, sizeof(buffer), "%*.*sA.bulk", k, k, file);
 		unlink (buffer);
 		fclose (gp);
 		gp = NULL;
@@ -763,7 +790,7 @@ ok_dot: ;
 
 	case 552: 
 	case 554: 
-no_dice: ;
+no_dice:
 	    result = RP_NDEL;
 	    if (k <= 0 || strcmp (sender, "<>\r\n") == 0) {
 		unlink (file);
@@ -775,7 +802,7 @@ no_dice: ;
 		fseek (gp, 0L, SEEK_SET);
 	    }
     	    else {
-		sprintf (buffer, "%*.*sA.bulk", k, k, file);
+		snprintf (buffer, sizeof(buffer), "%*.*sA.bulk", k, k, file);
 		if ((gp = fopen (buffer, "w")) == NULL)
 		    break;
 	    }
@@ -816,7 +843,7 @@ sm_ierror (char *fmt, ...)
     va_list ap;
 
     va_start(ap, fmt);
-    vsprintf (sm_reply.text, fmt, ap);
+    vsnprintf (sm_reply.text, sizeof(sm_reply.text), fmt, ap);
     va_end(ap);
 
     sm_reply.length = strlen (sm_reply.text);
@@ -834,7 +861,7 @@ smtalk (int time, char *fmt, ...)
     char buffer[BUFSIZ];
 
     va_start(ap, fmt);
-    vsprintf (buffer, fmt, ap);
+    vsnprintf (buffer, sizeof(buffer), fmt, ap);
     va_end(ap);
 
     if (sm_debug) {
@@ -854,18 +881,22 @@ smtalk (int time, char *fmt, ...)
 	        fflush (sm_wfp);
 	        if (ferror (sm_wfp))
 		    return sm_werror ();
-		sprintf (file, "%s%c.bulk", sm_tmpfil,
+		snprintf (file, sizeof(file), "%s%c.bulk", sm_tmpfil,
 				(char) (sm_ispool + 'a' - 1));
 		if (rename (sm_tmpfil, file) == NOTOK) {
-		    char   *bp;
-		    sprintf (bp = sm_reply.text,
-				    "error renaming %s to %s: ",
-				    sm_tmpfil, file);
-		    bp += strlen (bp);
+		    int len;
+		    char *bp;
+
+		    snprintf (sm_reply.text, sizeof(sm_reply.text),
+			    "error renaming %s to %s: ", sm_tmpfil, file);
+		    bp = sm_reply.text;
+		    len = strlen (bp);
+		    bp += len;
 		    if ((s = strerror (errno)))
-			strcpy (bp, s);
+			strncpy (bp, s, sizeof(sm_reply.text) - len);
 		    else
-			sprintf (bp, "unknown error %d", errno);
+			snprintf (bp, sizeof(sm_reply.text) - len,
+				"unknown error %d", errno);
 		    sm_reply.length = strlen (sm_reply.text);
 		    sm_reply.code = NOTOK;
 		    return RP_BHST;
@@ -980,16 +1011,17 @@ sm_wstream (char *buffer, int len)
 }
 
 
-#ifdef _AIX
 /*
- * AIX by default will inline the strlen and strcpy commands by redefining
- * them as __strlen and __strcpy respectively.  This causes compile problems
- * with the #ifdef MPOP in the middle.  Should the #ifdef MPOP be removed,
- * remove these #undefs.
+ * On some systems, strlen and strcpy are defined as preprocessor macros.  This
+ * causes compile problems with the #ifdef MPOP in the middle.  Should the
+ * #ifdef MPOP be removed, remove these #undefs.
  */
+#ifdef strlen
 # undef strlen
+#endif
+#ifdef strcpy
 # undef strcpy
-#endif /* _AIX */
+#endif
 
 static int
 sm_werror (void)
@@ -1085,7 +1117,8 @@ again: ;
 	    sm_reply.code = code;
 	    more = cont;
 	    if (bc <= 0) {
-		strcpy (bp = buffer, sm_noreply);
+		strncpy (buffer, sm_noreply, sizeof(buffer));
+		bp = buffer;
 		bc = strlen (sm_noreply);
 	    }
 	}
@@ -1193,7 +1226,7 @@ rp_string (int code)
 	case RP_BHST: 
 	default: 
 	    text = "BHST";
-	    sprintf (buffer, "[%s] %s", text, sm_reply.text);
+	    snprintf (buffer, sizeof(buffer), "[%s] %s", text, sm_reply.text);
 	    return buffer;
 
 	case RP_PARM: 
@@ -1213,7 +1246,8 @@ rp_string (int code)
 	    break;
     }
 
-    sprintf (buffer, "[%s] %3d %s", text, sm_reply.code, sm_reply.text);
+    snprintf (buffer, sizeof(buffer), "[%s] %3d %s",
+		text, sm_reply.code, sm_reply.text);
     return buffer;
 }
 
@@ -1268,11 +1302,12 @@ smail_brkany (char chr, char *strg)
  * copy a string array and return pointer to end
  */
 char **
-smail_copyip (char **p, char **q)
+smail_copyip (char **p, char **q, int len_q)
 {
-    while (*p)
+    while (*p && --len_q > 0)
 	*q++ = *p++;
-    *q = 0;
+
+    *q = NULL;
  
     return q;
 }
