@@ -2,7 +2,7 @@
 /*
  * error.c -- main error handling routines
  *
- * $Id$
+ * $Id: error.c,v 1.2 1999/05/13 01:31:00 dan Exp $
  */
 
 #include <h/mh.h>
@@ -12,7 +12,7 @@
 # include <sys/uio.h>
 #endif
 
-extern int errno;
+#include <errno.h>
 
 
 /*
@@ -89,7 +89,7 @@ advertise (char *what, char *tail, char *fmt, va_list ap)
 	iov++;
     }
     
-    vsnprintf (buffer, BUFSIZ, fmt, ap);
+    vsnprintf (buffer, sizeof(buffer), fmt, ap);
     iov->iov_len = strlen (iov->iov_base = buffer);
     iov++;
     if (what) {
@@ -103,7 +103,7 @@ advertise (char *what, char *tail, char *fmt, va_list ap)
 	}
         if (!(iov->iov_base = strerror (eindex))) {
 	    /* this shouldn't happen, but we'll test for it just in case */
-	    snprintf (err, BUFSIZ, "Error %d", eindex);
+	    snprintf (err, sizeof(err), "Error %d", eindex);
 	    iov->iov_base = err;
 	}
 	iov->iov_len = strlen (iov->iov_base);
