@@ -2,7 +2,7 @@
 /*
  * folder_addmsg.c -- Link message into folder
  *
- * $Id$
+ * $Id: folder_addmsg.c,v 1.1.1.1 1999/04/30 18:08:34 doug Exp $
  */
 
 #include <h/mh.h>
@@ -31,17 +31,23 @@ folder_addmsg (struct msgs **mpp, char *msgfile, int selected,
      * in order to add the message to the folder.
      */
     for (;;) {
+	/*
+	 * Get the message number we will attempt to add.
+	 */
 	if (first_time) {
 	    /* should we preserve the numbering of the message? */
 	    if (preserve && (msgnum = m_atoi (msgfile)) > 0) {
 		;
+	    } else if (mp->nummsg == 0) {
+		/* check if we are adding to empty folder */
+		msgnum = 1;
 	    } else {
 		/* else use highest message number + 1 */
 		msgnum = mp->hghmsg + 1;
 	    }
 	    first_time = 0;
 	} else {
-	    /* another attempt, try next higher number */
+	    /* another attempt, so try next higher message number */
 	    msgnum++;
 	}
 
@@ -71,13 +77,12 @@ folder_addmsg (struct msgs **mpp, char *msgfile, int selected,
 	 * If a message is already in that slot,
 	 * then loop to next available slot.
 	 */
-	if (does_exist (mp, msgnum)) {
+	if (does_exist (mp, msgnum))
 	    continue;
-	} else {
-	    clear_msg_flags (mp, msgnum);
-	    set_exists (mp, msgnum);
-	    mp->nummsg++;
-	}
+
+	/* setup the bit flags for this message */
+	clear_msg_flags (mp, msgnum);
+	set_exists (mp, msgnum);
 
 	/* should we set the SELECT_UNSEEN bit? */
 	if (unseen) {
@@ -88,19 +93,39 @@ folder_addmsg (struct msgs **mpp, char *msgfile, int selected,
 	if (selected) {
 	    set_selected (mp, msgnum);
 
-	    if (mp->lowsel == 0 || msgnum < mp->lowsel)
+	    /* check if highest or lowest selected */
+	    if (mp->numsel == 0) {
 		mp->lowsel = msgnum;
-	    if (msgnum > mp->hghsel)
 		mp->hghsel = msgnum;
+	    } else {
+		if (msgnum < mp->lowsel)
+		    mp->lowsel = msgnum;
+		if (msgnum > mp->hghsel)
+		    mp->hghsel = msgnum;
+	    }
+
+	    /* increment number selected */
+	    mp->numsel++;
 	}
 
-	if (mp->lowmsg == 0 || msgnum < mp->lowmsg)
+	/*
+	 * check if this is highest or lowest message
+         */
+	if (mp->nummsg == 0) {
 	    mp->lowmsg = msgnum;
-	if (msgnum > mp->hghmsg)
 	    mp->hghmsg = msgnum;
+	} else {
+	    if (msgnum < mp->lowmsg)
+		mp->lowmsg = msgnum;
+	    if (msgnum > mp->hghmsg)
+		mp->hghmsg = msgnum;
+	}
+
+	/* increment message count */
+	mp->nummsg++;
 
 	nmsg = m_name (msgnum);
-	snprintf (newmsg, BUFSIZ, "%s/%s", mp->foldpath, nmsg);
+	snprintf (newmsg, sizeof(newmsg), "%s/%s", mp->foldpath, nmsg);
 
 	/*
 	 * Now try to link message into folder
