@@ -2,7 +2,7 @@
 /*
  * m_backup.c -- construct a backup file
  *
- * $Id$
+ * $Id: m_backup.c,v 1.1.1.1 1999/04/30 18:08:34 doug Exp $
  */
 
 #include <h/mh.h>
@@ -15,9 +15,11 @@ m_backup (char *file)
     static char buffer[BUFSIZ];
 
     if ((cp = r1bindex(file, '/')) == file)
-	snprintf(buffer, BUFSIZ, "%s%s", BACKUP_PREFIX, cp);
+	snprintf(buffer, sizeof(buffer), "%s%s",
+		BACKUP_PREFIX, cp);
     else
-	snprintf(buffer, BUFSIZ, "%.*s%s%s", cp - file, file, BACKUP_PREFIX, cp);
+	snprintf(buffer, sizeof(buffer), "%.*s%s%s", cp - file, file,
+		BACKUP_PREFIX, cp);
 
     unlink(buffer);
     return buffer;
