@@ -2,7 +2,7 @@
 /*
  * m_draft.c -- construct the name of a draft message
  *
- * $Id$
+ * $Id: m_draft.c,v 1.1.1.1 1999/04/30 18:08:34 doug Exp $
  */
 
 #include <h/mh.h>
@@ -23,15 +23,15 @@ m_draft (char *folder, char *msg, int use, int *isdf)
 	if (*isdf == -1 || (cp = context_find ("Draft-Folder")) == NULL) {
 	    *isdf = 0;
 	    return m_maildir (msg && *msg ? msg : draft);
-	}
-	else
+	} else {
 	    folder = path (*cp == '+' || *cp == '@' ? cp + 1 : cp,
 		    *cp != '@' ? TFOLDER : TSUBCWF);
+	}
     }
     *isdf = 1;
     
     chdir (m_maildir (""));
-    strcpy (buffer, m_maildir (folder));
+    strncpy (buffer, m_maildir (folder), sizeof(buffer));
     if (stat (buffer, &st) == -1) {
 	if (errno != ENOENT)
 	    adios (buffer, "error on folder");
@@ -77,7 +77,7 @@ m_draft (char *folder, char *msg, int use, int *isdf)
     if (mp->numsel > 1)
 	adios (NULL, "only one message draft at a time!");
 
-    snprintf (buffer, BUFSIZ, "%s/%s", mp->foldpath, m_name (mp->lowsel));
+    snprintf (buffer, sizeof(buffer), "%s/%s", mp->foldpath, m_name (mp->lowsel));
     cp = buffer;
 
     seq_setcur (mp, mp->lowsel);/* set current message for folder */
