@@ -2,7 +2,7 @@
 /*
  * m_getfld.c -- read/parse a message
  *
- * $Id: m_getfld.c,v 1.4 1999/09/12 13:50:12 doug Exp $
+ * $Id: m_getfld.c,v 1.6 2000/01/26 21:35:43 danh Exp $
  */
 
 #include <h/mh.h>
@@ -184,6 +184,7 @@ static int (*eom_action)() = NULL;
 # define _ptr    _p		/* Gag   */
 # define _cnt    _r		/* Retch */
 # define _filbuf __srget	/* Puke  */
+# define DEFINED__FILBUF_TO_SOMETHING_SPECIFIC
 #endif
 
 #ifdef SCO_5_STDIO
@@ -191,6 +192,11 @@ static int (*eom_action)() = NULL;
 # define _cnt  __cnt
 # define _base __base
 # define _filbuf(fp)  ((fp)->__cnt = 0, __filbuf(fp))
+# define DEFINED__FILBUF_TO_SOMETHING_SPECIFIC
+#endif
+
+#ifndef DEFINED__FILBUF_TO_SOMETHING_SPECIFIC
+extern int  _filbuf(FILE*);
 #endif
 
 
@@ -572,7 +578,7 @@ m_unknown(FILE *iob)
     pat_map = (unsigned char **) calloc (256, sizeof(unsigned char *));
 
     for (cp = (char *) fdelim + 1; cp < (char *) delimend; cp++ )
-	pat_map[*cp] = (unsigned char *) cp;
+	pat_map[(unsigned char)*cp] = (unsigned char *) cp;
 
     if (msg_style == MS_MMDF) {
 	/* flush extra msg hdrs */
