@@ -2,7 +2,7 @@
 /*
  * dropsbr.c -- create/read/manipulate mail drops
  *
- * $Id: dropsbr.c,v 1.1.1.1 1999/04/30 18:08:35 doug Exp $
+ * $Id: dropsbr.c,v 1.2 2000/03/28 14:42:36 doug Exp $
  */
 
 #include <h/nmh.h>
@@ -408,8 +408,7 @@ mbx_copy (char *mailbox, int mbx_style, int md, int fd,
 			strncpy(tmpbuffer, buffer, sizeof(tmpbuffer));
 			ep = "nobody@nowhere";
 			tp = dctime(dlocaltimenow());
-			snprintf (buffer, sizeof(buffer), "From %s  %s", ep, tp);
-			strcat (buffer, tmpbuffer);
+			snprintf (buffer, sizeof(buffer), "From %s  %s%s", ep, tp, tmpbuffer);
 		    }
 		}
 
