@@ -2,7 +2,7 @@
 /*
  * msgchk.c -- check for mail
  *
- * $Id: msgchk.c,v 1.4 2000/02/04 20:28:24 danh Exp $
+ * $Id: msgchk.c,v 1.5 2000/03/17 20:11:04 danh Exp $
  */
 
 #include <h/mh.h>
@@ -259,6 +259,9 @@ main (int argc, char **argv)
 
 #ifdef POP
     if (host) {
+	if ( strcmp( POPSERVICE, "kpop" ) == 0 ) {
+	    kpop = 1;
+	}
 	if (vecp == 0) {
 	    status = remotemail (host, user, rpop, kpop, notifysw, 1, snoop);
 	} else {
