@@ -2,7 +2,7 @@
 /*
  * msh.c -- The nmh shell
  *
- * $Id: msh.c,v 1.3 2000/02/04 20:28:24 danh Exp $
+ * $Id: msh.c,v 1.4 2000/03/06 20:19:04 danh Exp $
  */
 
 /*
@@ -754,7 +754,7 @@ setup (char *file)
     if (!(mp = (struct msgs  *) calloc ((size_t) 1, sizeof(*mp))))
 	padios (NULL, "unable to allocate folder storage");
 
-    if (!(mp->msgstats = calloc ((size_t) 1, msgp + 3)))
+    if (!(mp->msgstats = calloc ((size_t) msgp + 3, sizeof(*(mp->msgstats)))))
 	padios (NULL, "unable to allocate message status storage");
 
     mp->hghmsg = msgp;
