@@ -2,7 +2,7 @@
 /*
  * slocal.c -- asynchronously filter and deliver new mail
  *
- * $Id: slocal.c,v 1.7 2000/02/04 20:28:24 danh Exp $
+ * $Id: slocal.c,v 1.9 2000/03/02 07:52:47 danh Exp $
  */
 
 /*
@@ -29,14 +29,16 @@
 #include <sys/ioctl.h>
 #include <fcntl.h>
 
-#include <grp.h>     /* initgroups() is here on Solaris 2.6 */
-#include <unistd.h>  /* initgroups() is here on HP-UX 10.20 */
-
+#ifdef INITGROUPS_HEADER
+#include INITGROUPS_HEADER
+#else
 /* On AIX 4.1, initgroups() is defined and even documented (giving the parameter
-   types as "char*" and "int"), but doesn't have a prototype in any of the
-   system header files.  On other OSes, this should be a duplicate prototype
-   that won't cause any errors or warnings. */
-extern int  initgroups(const char*, gid_t);
+   types as char* and int), but doesn't have a prototype in any of the system
+   header files.  AIX 4.3, SunOS 4.1.3, and ULTRIX 4.2A have the same
+   problem. */
+extern int  initgroups(char*, int);
+#endif
+
 
 #ifdef HAVE_DB1_NDBM_H
 #include <db1/ndbm.h>
