@@ -2,7 +2,7 @@
 /*
  * dtime.c -- time/date routines
  *
- * $Id: dtime.c,v 1.3 2000/01/25 06:05:25 danh Exp $
+ * $Id: dtime.c,v 1.4 2000/03/14 05:24:57 danh Exp $
  */
 
 #include "h/mh.h"   /* for snprintf() */
@@ -460,6 +460,8 @@ set_dotw (struct tws *tw)
     tw->tw_wday =
 	((26 * month - 2) / 10 + day + year + year / 4
 	    - 3 * century / 4 + 1) % 7;
+    if (tw->tw_wday < 0)
+	tw->tw_wday += 7;
 
     tw->tw_flags &= ~TW_SDAY, tw->tw_flags |= TW_SIMP;
 }
